<?php

/*
 * Plugin Name: DS Gallery
 * Plugin URI: http://chips-ny.com
 * Description: Get all images from a post with a quick shortcode
 * Version: 0.3
 * Author: Dan Shields
 * Author URI: http://chips-ny.com
 * License: GPLv3
 *
 * Copyright (C) 2012 CHIPS
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */
 

if ( !function_exists( 'dsGalleryImages' ) ) {
	function dsGalleryImages( $smSize = "thumbnail", $linkSize = "large", $ignoreFeatured=FALSE, $extraClasses = "" ){
		global $post;
		// Gather plugin options
		$extraClass = "";
		$showthumbs = get_option('dsgal_showthumbs');
		$transition = get_option('dsgal_transition');
		$dsgal_width = get_option('dsgal_width');
		$dsgal_height = get_option('dsgal_height');
		$dsGalSlideMargin = get_option('dsGalSlideMargin'); if($dsGalSlideMargin==""){$dsGalSlideMargin=30;}
		$dsGalTransitionSpeed = get_option('dsGalTransitionSpeed'); if($dsGalTransitionSpeed==""){$dsGalTransitionSpeed=300;}
		$dsgal_showarrows = get_option('dsgal_showarrows');
		$dsGalArrowImg = get_option('dsGalArrowImg');
		$dsGalArrowW = get_option('dsGalArrowW');
		$dsGalArrowH = get_option('dsGalArrowH');
		$dsGalArrowTouch = get_option('dsGalArrowTouch');
		$dsGalIncludejQuery = get_option('dsGalIncludejQuery');
		$dsGalArrowKeys = get_option('dsGalArrowKeys'); if($dsGalArrowKeys == "Yes"){ $extraClass .= " arrowKeysOn"; }
		$dsGalImgClick = get_option('dsGalImgClick'); if($dsGalImgClick == "Yes"){ $extraClass .= " imgClickOn"; }
		$dsArrowChoice = get_option('dsArrowChoice'); $extraClass .= " ".$dsArrowChoice;
		if($smSize == ""){ $smSize = "thumbnail"; }

		if (empty($post_id)){$post_id = $post->ID;}
		$args = array( 'post_type' => 'attachment', 'numberposts' => -1,'order'=> 'ASC', 'post_status' => null, 'post_parent' => $post_id, 'orderby' => 'menu_order' ); 
		$attachments = get_posts($args);
		if ($attachments && count($attachments)>1) {
			echo "<div class=\"ds-gallery-full clearfix ds-gal-".$transition." touch-arrows-" . $dsGalArrowTouch . $extraClass . "\" style=\"";
			if($dsgal_width != ""){ print "width:".$dsgal_width."; "; }
			if($dsgal_height != ""){ print "height:".$dsgal_height."; "; }
			print "\">";
			if(isset($dsgal_showarrows) && $dsgal_showarrows != "No"){
				print "<div class=\"dsGalArrow dsGalArrowL\"></div><div class=\"dsGalArrow dsGalArrowR\"></div>";
			}
			print "<ul id=\"ds-gal\" class=\"clearfix\"><li class=\"starter-Width\"></li><li class=\"overImgLayer\"></li>";
			$keepTrackImg = 1;
			foreach ( $attachments as $attachment ) {
				$large_image_url = wp_get_attachment_image_src( $attachment->ID, $linkSize);
				
				print "<li id=\"ds-gallery-large-".$keepTrackImg."\" class=\"ds-gallery-large\">";
				if($keepTrackImg==1){
					print wp_get_attachment_image($attachment->ID, $linkSize);
				} else { 
					print "<a href=\"".$large_image_url[0]."\"></a>";
				}
				print "</li>";
				$keepTrackImg++;
			}
			echo "</ul></div>";
			
			if($showthumbs!="No"){
				echo "<div class=\"ds-gallery clearfix\"><ul>";
				$keepTrackImg = 1;
				foreach ( $attachments as $attachment ) {
					$large_image_url = wp_get_attachment_image_src( $attachment->ID, $linkSize);
					$tempText = htmlentities($attachment->post_title . " <br /><span>" . $attachment->post_excerpt . "</span>");
					$finalImg = "<li id=\"ds-gallery-item-".$keepTrackImg."\" rel=\"img-group-".$post_id."\" class=\"ds-gallery-item\"><a href=\"".$large_image_url[0]."\" rel=\"".$keepTrackImg."\" class=\"dsGalleryImg ".$extraClasses."\" title=\"".$tempText."\">".wp_get_attachment_image($attachment->ID, $smSize)."</a></li>";
				
					if($ignoreFeatured==TRUE){
						if(get_post_thumbnail_id( get_the_id() ) != $attachment->ID) {
							print $finalImg;
						}
					} else {
						print $finalImg;
					}
				
					$keepTrackImg++;
				}
				echo "</ul></div>";
			}
		}
		wp_enqueue_style('ds-gallery-styles', WP_PLUGIN_URL . '/'.basename(dirname(__FILE__)).'/css/style.css');
		//wp_enqueue_script('ds-jquery', WP_PLUGIN_URL . '/'.basename(dirname(__FILE__)).'/js/jquery.js');
		if($dsGalIncludejQuery=="Yes"){
			wp_deregister_script( 'jquery' );
			wp_register_script( 'jquery', 'http://ajax.googleapis.com/ajax/libs/jquery/1.7.2/jquery.min.js');
		    wp_enqueue_script( 'jquery' );
		}
		wp_enqueue_script('ds-gallery-scripts', WP_PLUGIN_URL . '/'.basename(dirname(__FILE__)).'/js/script.js');
		
?>
		<script type="text/Javascript">
			window.onload = function() { 
				dsGalObj.dsGalSlideMargin = <?=$dsGalSlideMargin?>;
				dsGalObj.dsGalStarterW = 0;
				dsGalObj.dsGalTransitionSpeed = <?=$dsGalTransitionSpeed?>;
			}
		</script>
<?php
	}
}
function dsgallery_admin() {
	include('ds-gallery-admin.php');
}

function dsgallery_admin_actions() {
    add_options_page("DS Gallery Settings", "DS Gallery", 1, "DSGallerySettings", "dsgallery_admin");
}

function prepShortcode($attr = ""){
	$smSize = "thumbnail";
	$linkSize = "large";
	$ignoreFeatured = FALSE;
	$extraClasses = "";
	if(isset($attr) && $attr != ""){
		foreach($attr as $k => $v){
			if($k == "smsize"){ $smSize = $v; }
			if($k == "linksize"){ $linkSize = $v; }
			if($k == "ignorefeatured"){ $ignoreFeatured = $v; }
			if($k == "extraclasses"){ $extraClasses = $v; }
		}
	}
	dsGalleryImages($smSize,$linkSize,$ignoreFeatured,$extraClasses);
}
add_action('admin_menu','dsgallery_admin_actions');
add_shortcode( 'dsGalleryImages', 'prepShortcode' );

?>
